{
  config,
  pkgs,
  lib,
  ...
}:
with lib; let
  cfg = config.features.desktop.hyprland;
in {
  imports = [
    ../common
    ./dotfiles
    ./home.nix
    ../features/cli
    ../features/coding
    ../features/desktop
    ./services/librechat.nix
  ];

  options.features.desktop.hyprland.enable =
    mkEnableOption "enable Hyprland";

  config = mkMerge [
    # Base configuration
    {
      features = {
        cli = {
          fish.enable = true;
          fzf.enable = true;
          neofetch.enable = true;
          secrets.enable = true;
          starship.enable = true;
        };
        desktop = {
          gaming.enable = true;
          hyprland.enable = true;
          media.enable = true;
          office.enable = true;
          rofi.enable = true;
          fonts.enable = true;
          wayland.enable = true;
        };
      };
    }

    (mkIf cfg.enable {
      wayland.windowManager.hyprland = {
        enable = true;
        settings = {
          monitor = [
            "DP-1,2560x1440@144,0x0,1"
            "DP-2,2560x1440@144,2560x0,1"
          ];
          workspace = [
            "1, monitor:DP-1, default:true"
            "2, monitor:DP-1"
            "3, monitor:DP-1"
            "4, monitor:DP-2"
            "5, monitor:DP-1"
            "6, monitor:DP-2"
            "7, monitor:DP-2"
          ];

          windowrulev2 = [
            "workspace 1,class:dev.zed.Zed"
            "workspace 2,class:(com.obsproject.Studio)"
            "workspace 4,opacity 1.0, class:(chromium-browser)"
            "workspace 4,opacity 1.0, class:(zen-alpha)"
          ];
        };
      };
    })
  ];
}
